@@ -2,13 +2,14 @@ import json
 import logging
 from datetime import datetime, timedelta
 from functools import wraps
-from os import environ, path
+from os import getenv, path
 from typing import Dict, Optional
 
 from disnake import Client, Guild
 from dotenv import load_dotenv
 from ics import Calendar, ContentLine, Event
 from ics.alarm import DisplayAlarm
+from oauthlib.oauth2 import TokenExpiredError
 from quart import Quart, redirect, render_template, request, session, url_for
 from requests_oauthlib import OAuth2Session  # type: ignore
 from uvicorn.middleware.proxy_headers import ProxyHeadersMiddleware  # type: ignore
@@ -16,9 +17,9 @@ from uvicorn.middleware.proxy_headers import ProxyHeadersMiddleware  # type: ign
 
 load_dotenv()
 
-DISCORD_TOKEN = environ.get("DISCORD_TOKEN")
-OAUTH2_CLIENT_ID = environ.get("OAUTH2_CLIENT_ID")
-OAUTH2_CLIENT_SECRET = environ.get("OAUTH2_CLIENT_SECRET")
+DISCORD_TOKEN = getenv("DISCORD_TOKEN")
+OAUTH2_CLIENT_ID = getenv("OAUTH2_CLIENT_ID")
+OAUTH2_CLIENT_SECRET = getenv("OAUTH2_CLIENT_SECRET")
 if not DISCORD_TOKEN:
     raise Exception("Missing DISCORD_TOKEN")
 if not OAUTH2_CLIENT_ID:
@@ -26,11 +27,11 @@ if not OAUTH2_CLIENT_ID:
 if not OAUTH2_CLIENT_SECRET:
     raise Exception("Missing OAUTH2_CLIENT_SECRET")
 
-QUART_DEBUG = environ.get("QUART_DEBUG", False)
+QUART_DEBUG = getenv("QUART_DEBUG", False)
 if QUART_DEBUG:
     logging.basicConfig(level=logging.DEBUG)
 
-API_BASE_URL = environ.get("API_BASE_URL", "https://discordapp.com/api")
+API_BASE_URL = getenv("API_BASE_URL", "https://discordapp.com/api")
 AUTHORIZATION_BASE_URL = f"{API_BASE_URL}/oauth2/authorize"
 TOKEN_URL = f"{API_BASE_URL}/oauth2/token"
 
@@ -180,9 +181,12 @@ async def guilds():
             url_for(".subscribe", guild_id=guild.vanity_url_code or guild.id)
         )
 
-    discord = make_session(token=session.get("oauth2_token"))
-    user = discord.get(f"{API_BASE_URL}/users/@me").json()
-    user_guilds = discord.get(f"{API_BASE_URL}/users/@me/guilds").json()
+    try:
+        discord = make_session(token=session.get("oauth2_token"))
+        user = discord.get(f"{API_BASE_URL}/users/@me").json()
+        user_guilds = discord.get(f"{API_BASE_URL}/users/@me/guilds").json()
+    except TokenExpiredError:
+        return redirect(url_for(".login"))
 
     common_guilds = []
     for bot_guild in client.guilds:
@@ -202,8 +206,11 @@ async def subscribe(guild_id: str):
     if guild is None:
         return redirect(url_for(".login"))
 
-    discord = make_session(token=session.get("oauth2_token"))
-    user_guilds = discord.get(f"{API_BASE_URL}/users/@me/guilds").json()
+    try:
+        discord = make_session(token=session.get("oauth2_token"))
+        user_guilds = discord.get(f"{API_BASE_URL}/users/@me/guilds").json()
+    except TokenExpiredError:
+        return redirect(url_for(".login"))
 
     if not any(str(guild.id) == user_guild["id"] for user_guild in user_guilds):
         return redirect(url_for(".login"))
@@ -253,6 +260,7 @@ async def ical(guild_id: str):
     return calendar.serialize()
 
 
-quart_task = client.loop.create_task(app.run_task("0.0.0.0"))
-quart_task.add_done_callback(lambda f: client.loop.stop())
-client.run(DISCORD_TOKEN)
+def __main__():
+    quart_task = client.loop.create_task(app.run_task("0.0.0.0"))
+    quart_task.add_done_callback(lambda f: client.loop.stop())
+    client.run(DISCORD_TOKEN)
